ALL_OF_THE_TIME = "all_of_the_time"
CONFINED_TO_BED = "confined_to_bed"
EXTREME_ANXIOUS_DEPRESSED = "extremely_anxious_depressed"
EXTREME_PAIN_DISCOMFORT = "extreme_pain_discomfort"
GOOD_BIT_OF_THE_TIME = "good_bit_of_the_time"
LITTLE_OF_THE_TIME = "little_of_the_time"
MODERATE_ANXIOUS_DEPRESSED = "moderately_anxious_depressed"
MODERATE_PAIN_DISCOMFORT = "moderate_pain_discomfort"
MOST_OF_THE_TIME = "most_of_the_time"
NONE_OF_THE_TIME = "none_of_the_time"
NOT_ANXIOUS_DEPRESSED = "not_anxious_depressed"
NO_PAIN_DISCOMFORT = "no_pain_discomfort"
NO_PROBLEM_SELF_CARE = "no_problems_with_self_care"
NO_PROBLEM_USUAL_ACTIVITIES = "no_problems_performing_usual_activities"
NO_PROBLEM_WALKING = "no_problems_in_walking"
PROBLEM_WASHING_DRESSING = "problems_washing_dressing_myself"
SOME_OF_THE_TIME = "some_of_the_time"
SOME_PROBLEM_USUAL_ACTIVITIES = "some_problems_performing_usual_activities"
SOME_PROBLEM_WALKING = "some_problems_in_walking"
UNABLE_PERFORM_USUAL_ACTIVITIES = "unable_to_perform_usual_activities"
UNABLE_WASH_DRESS = "unable_to_wash_dress_myself"



from django.contrib import admin
from django.utils.html import format_html
from django_audit_fields.admin import audit_fieldset_tuple
from edc_model_admin import ModelAdminInstitutionMixin, SimpleHistoryAdmin

from ..admin_site import edc_qol_admin
from ..forms import Eq5d3lForm
from ..models import Eq5d3l

eq5d3l_description = """
<H5><B><font color="orange">Interviewer to read</font></B></H5>
<p>We would like to know how good or bad your health is TODAY.
<ul><li>This scale is numbered from 0 to 100;</li>
<li>100 means the <U>best</U> health you can imagine;</li>
<li>0 means the <U>worst</U> health you can imagine;</li>
<li>Drag the slider on the line below at the point
showing how your health is TODAY</li></ul>
<BR><BR>
</p>
"""


def eq5d3l_fieldsets():
    return [
        (
            "Describe your health TODAY ...",
            {
                "description": (
                    "Under each heading, please tick the ONE box "
                    "that best describes your health TODAY."
                ),
                "fields": (
                    "mobility",
                    "self_care",
                    "usual_activities",
                    "pain_discomfort",
                    "anxiety_depression",
                ),
            },
        ),
        (
            "How is your health TODAY?",
            {
                "description": format_html(eq5d3l_description),
                "fields": (
                    "health_today_score_slider",
                    "health_today_score_confirmed",
                ),
            },
        ),
    ]


def eq5d3l_radio_fields():
    return {
        "mobility": admin.VERTICAL,
        "self_care": admin.VERTICAL,
        "usual_activities": admin.VERTICAL,
        "pain_discomfort": admin.VERTICAL,
        "anxiety_depression": admin.VERTICAL,
    }


@admin.register(Eq5d3l, site=edc_qol_admin)
class Eq5d3lAdmin(ModelAdminInstitutionMixin, SimpleHistoryAdmin):

    form = Eq5d3lForm

    fieldsets = (
        (None, {"fields": ("subject_identifier", "report_datetime")}),
        *eq5d3l_fieldsets(),
        audit_fieldset_tuple,
    )

    radio_fields = eq5d3l_radio_fields()



from django.core.validators import MaxValueValidator, MinValueValidator
from django.db import models
from django.utils.html import format_html

from ..choices import (
    ANXIETY_DEPRESSION,
    MOBILITY,
    PAIN_DISCOMFORT,
    SELF_CARE,
    USUAL_ACTIVITIES,
)


class Eq5d3lModelMixin(models.Model):

    mobility = models.CharField(verbose_name="Mobility", max_length=45, choices=MOBILITY)

    self_care = models.CharField(verbose_name="Self-care", max_length=45, choices=SELF_CARE)

    usual_activities = models.CharField(
        verbose_name="Usual activities",
        max_length=45,
        help_text="Example. work, study, housework, family or leisure activities",
        choices=USUAL_ACTIVITIES,
    )

    pain_discomfort = models.CharField(
        verbose_name="Pain / Discomfort", max_length=45, choices=PAIN_DISCOMFORT
    )

    anxiety_depression = models.CharField(
        verbose_name="Anxiety / Depression", max_length=45, choices=ANXIETY_DEPRESSION
    )

    health_today_score_slider = models.CharField(
        verbose_name=format_html("Visual score for how your health is TODAY"),
        max_length=3,
    )

    health_today_score_confirmed = models.IntegerField(
        verbose_name=format_html(
            "<B><font color='orange'>Interviewer</font></B>: "
            "please confirm the number on the scale indicated from above."
        ),
        validators=[MinValueValidator(0), MaxValueValidator(100)],
        help_text=(
            "This scale is numbered from 0 to 100. "
            "100 means the <U>best</U> health you can imagine"
            "0 means the <U>worst</U> health you can imagine."
        ),
    )

    class Meta:
        abstract = True
        verbose_name = "EuroQol EQ-5D-3L Instrument"
        verbose_name_plural = "EuroQol EQ-5D-3L Instrument"



from django.apps import apps as django_apps
from django.conf import settings
from django.db import models

# don't delete. so attr is searchable
EDC_QOL_EQ5D3L_MODEL = "EDC_QOL_EQ5D3L_MODEL"
EDC_QOL_SF12_MODEL = "EDC_QOL_SF12_MODEL"


def get_qol_eq5d3l_model_name() -> str:
    return getattr(settings, EDC_QOL_EQ5D3L_MODEL, "edc_qol.eq5d3l")


def get_qol_eq5d3l_model_cls() -> models.Model:
    return django_apps.get_model(get_qol_eq5d3l_model_name())


def get_qol_sf12_model_name() -> str:
    return getattr(settings, EDC_QOL_SF12_MODEL, "edc_qol.sf12")


def get_qol_sf12_model_cls() -> models.Model:
    return django_apps.get_model(get_qol_sf12_model_name())



from django.test import TestCase

from edc_qol.models import Eq5d3l

from .mixins import TestCaseMixin


class TestEq5d3lModel(TestCaseMixin, TestCase):
    def test_pass(self):
        Eq5d3l()
        self.assertTrue(True)



from .constants import (
    ALL_OF_THE_TIME,
    CONFINED_TO_BED,
    EXTREME_ANXIOUS_DEPRESSED,
    EXTREME_PAIN_DISCOMFORT,
    GOOD_BIT_OF_THE_TIME,
    LITTLE_OF_THE_TIME,
    MODERATE_ANXIOUS_DEPRESSED,
    MODERATE_PAIN_DISCOMFORT,
    MOST_OF_THE_TIME,
    NO_PAIN_DISCOMFORT,
    NO_PROBLEM_SELF_CARE,
    NO_PROBLEM_USUAL_ACTIVITIES,
    NO_PROBLEM_WALKING,
    NONE_OF_THE_TIME,
    NOT_ANXIOUS_DEPRESSED,
    PROBLEM_WASHING_DRESSING,
    SOME_OF_THE_TIME,
    SOME_PROBLEM_USUAL_ACTIVITIES,
    SOME_PROBLEM_WALKING,
    UNABLE_PERFORM_USUAL_ACTIVITIES,
    UNABLE_WASH_DRESS,
)

DESCRIBE_HEALTH_CHOICES = (
    ("excellent", "Excellent"),
    ("very_good", "Very good"),
    ("good", "Good"),
    ("fair", "Fair"),
    ("poor", "Poor"),
)

FEELING_DURATION_CHOICES = (
    (ALL_OF_THE_TIME, "All of the time"),
    (MOST_OF_THE_TIME, "Most of the time"),
    (GOOD_BIT_OF_THE_TIME, " A good bit of the time"),
    (SOME_OF_THE_TIME, "Some of the time"),
    (LITTLE_OF_THE_TIME, "A little of the time"),
    (NONE_OF_THE_TIME, "None of the time"),
)

HEALTH_LIMITED_CHOICES = (
    ("limited_a_lot", "YES, limited a lot"),
    ("limited_a_little", "YES, limited a little"),
    ("not_limited_at_all", "NO, not at all limited"),
)

INTERFERENCE_DURATION_CHOICES = (
    (ALL_OF_THE_TIME, "All of the time"),
    (MOST_OF_THE_TIME, "Most of the time"),
    (SOME_OF_THE_TIME, "Some of the time"),
    (LITTLE_OF_THE_TIME, "A little of the time"),
    (NONE_OF_THE_TIME, "None of the time"),
)

MOBILITY = (
    (NO_PROBLEM_WALKING, "I have no problems in walking about"),
    (SOME_PROBLEM_WALKING, "I have some problems in walking about"),
    (CONFINED_TO_BED, "I am confined to bed"),
)

SELF_CARE = (
    (NO_PROBLEM_SELF_CARE, "I have no problems with self-care"),
    (PROBLEM_WASHING_DRESSING, "I have some problems washing or dressing myself"),
    (UNABLE_WASH_DRESS, "I am unable to wash or dress myself"),
)

USUAL_ACTIVITIES = (
    (NO_PROBLEM_USUAL_ACTIVITIES, "I have no problems with performing my usual activities"),
    (
        SOME_PROBLEM_USUAL_ACTIVITIES,
        "I have some problems with performing my usual activities",
    ),
    (UNABLE_PERFORM_USUAL_ACTIVITIES, "I am unable to perform my usual activities"),
)

PAIN_DISCOMFORT = (
    (NO_PAIN_DISCOMFORT, "I have no pain or discomfort"),
    (MODERATE_PAIN_DISCOMFORT, "I have moderate pain or discomfort"),
    (EXTREME_PAIN_DISCOMFORT, "I have extreme pain or discomfort"),
)

ANXIETY_DEPRESSION = (
    (NOT_ANXIOUS_DEPRESSED, "I am not anxious or depressed"),
    (MODERATE_ANXIOUS_DEPRESSED, "I am moderately anxious or depressed"),
    (EXTREME_ANXIOUS_DEPRESSED, "I am extremely anxious or depressed"),
)

WORK_PAIN_INTERFERENCE_CHOICES = (
    ("not_at_all", "Not at all"),
    ("a_little_bit", "A little bit"),
    ("moderately", "Moderately"),
    ("quite_a-bit", "Quite a bit"),
    ("extremely", "Extremely"),
)
